@@ -99,7 +99,7 @@ fn make_request(
 /// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.ex#L137
 ///
 /// https://github.com/hexpm/hex/blob/main/lib/hex/api/key.ex#L6
-pub fn create_api_key_request(
+pub fn api_create_api_key_request(
     username: &str,
     password: &str,
     key_name: &str,
@@ -121,7 +121,7 @@ pub fn create_api_key_request(
 }
 
 /// Parses a request that creates a Hex API key.
-pub fn create_api_key_response(response: http::Response<Vec<u8>>) -> Result<String, ApiError> {
+pub fn api_create_api_key_response(response: http::Response<Vec<u8>>) -> Result<String, ApiError> {
     #[derive(Deserialize)]
     struct Resp {
         secret: String,
@@ -142,7 +142,7 @@ pub fn create_api_key_response(response: http::Response<Vec<u8>>) -> Result<Stri
 /// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.user.ex#L291
 ///
 /// https://github.com/hexpm/hex/blob/main/lib/hex/api/key.ex#L15
-pub fn remove_api_key_request(
+pub fn api_remove_api_key_request(
     name_of_key_to_delete: &str,
     api_key: &str,
     config: &Config,
@@ -158,7 +158,7 @@ pub fn remove_api_key_request(
 }
 
 /// Parses a request that deleted a Hex API key.
-pub fn remove_api_key_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
+pub fn api_remove_api_key_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
     let (parts, body) = response.into_parts();
     match parts.status {
         StatusCode::NO_CONTENT | StatusCode::OK => Ok(()),
@@ -175,7 +175,7 @@ pub fn remove_api_key_response(response: http::Response<Vec<u8>>) -> Result<(),
 /// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.retire.ex#L75
 ///
 /// https://github.com/hexpm/hex/blob/main/lib/hex/api/release.ex#L28
-pub fn retire_release_request(
+pub fn api_retire_release_request(
     package: &str,
     version: &str,
     reason: RetirementReason,
@@ -198,7 +198,7 @@ pub fn retire_release_request(
 }
 
 /// Parses a request that retired a release.
-pub fn retire_release_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
+pub fn api_retire_release_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
     let (parts, body) = response.into_parts();
     match parts.status {
         StatusCode::NO_CONTENT | StatusCode::OK => Ok(()),
@@ -215,7 +215,7 @@ pub fn retire_release_response(response: http::Response<Vec<u8>>) -> Result<(),
 /// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.retire.ex#L89
 ///
 /// https://github.com/hexpm/hex/blob/main/lib/hex/api/release.ex#L35
-pub fn unretire_release_request(
+pub fn api_unretire_release_request(
     package: &str,
     version: &str,
     api_key: &str,
@@ -232,7 +232,7 @@ pub fn unretire_release_request(
 }
 
 /// Parses a request that un-retired a package version.
-pub fn unretire_release_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
+pub fn api_unretire_release_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
     let (parts, body) = response.into_parts();
     match parts.status {
         StatusCode::NO_CONTENT | StatusCode::OK => Ok(()),
@@ -244,8 +244,11 @@ pub fn unretire_release_response(response: http::Response<Vec<u8>>) -> Result<()
 
 /// Create a request that get the names and versions of all of the packages on
 /// the package registry.
+///
+/// https://github.com/hexpm/specifications/blob/main/registry-v2.md
+///
 /// TODO: Where are the API docs for this?
-pub fn get_repository_versions_request(
+pub fn repository_v2_get_versions_request(
     api_key: Option<&str>,
     config: &Config,
 ) -> http::Request<Vec<u8>> {
@@ -256,10 +259,9 @@ pub fn get_repository_versions_request(
         .expect("get_repository_versions_request request")
 }
 
-/// Parse a request that get the names and versions of all of the packages on
+/// Parse a request that gets the names and versions of all of the packages on
 /// the package registry.
-///
-pub fn get_repository_versions_response(
+pub fn repository_v2_get_versions_response(
     response: http::Response<Vec<u8>>,
     public_key: &[u8],
 ) -> Result<HashMap<String, Vec<Version>>, ApiError> {
@@ -274,7 +276,15 @@ pub fn get_repository_versions_response(
     let mut body = Vec::new();
     decoder.read_to_end(&mut body)?;
 
-    let signed = Signed::decode(body.as_slice())?;
+    repository_v2_get_versions_body(&body, public_key)
+}
+
+/// Parse a signed binary message containing all of the packages on the package registry.
+pub fn repository_v2_get_versions_body(
+    protobuf_bytes: &Vec<u8>,
+    public_key: &[u8],
+) -> Result<HashMap<String, Vec<Version>>, ApiError> {
+    let signed = Signed::decode(protobuf_bytes.as_slice())?;
 
     let payload =
         verify_payload(signed, public_key).map_err(|_| ApiError::IncorrectPayloadSignature)?;
@@ -301,12 +311,9 @@ pub fn get_repository_versions_response(
 
 /// Create a request to get the information for a package in the repository.
 ///
-/// API Docs:
+/// https://github.com/hexpm/specifications/blob/main/registry-v2.md
 ///
-/// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.package.ex#L348
-///
-/// https://github.com/hexpm/hex/blob/main/lib/hex/api/package.ex#L36
-pub fn get_package_request(
+pub fn repository_v2_get_package_request(
     name: &str,
     api_key: Option<&str>,
     config: &Config,
@@ -320,7 +327,7 @@ pub fn get_package_request(
 
 /// Parse a response to get the information for a package in the repository.
 ///
-pub fn get_package_response(
+pub fn repository_v2_get_package_response(
     response: http::Response<Vec<u8>>,
     public_key: &[u8],
 ) -> Result<Package, ApiError> {
@@ -339,7 +346,15 @@ pub fn get_package_response(
     let mut body = Vec::new();
     decoder.read_to_end(&mut body)?;
 
-    let signed = Signed::decode(body.as_slice())?;
+    repository_v2_package_parse_body(&body, public_key)
+}
+
+/// Parse a signed binary message containing the information for a package in the repository.
+pub fn repository_v2_package_parse_body(
+    protobuf_bytes: &Vec<u8>,
+    public_key: &[u8],
+) -> Result<Package, ApiError> {
+    let signed = Signed::decode(protobuf_bytes.as_slice())?;
 
     let payload =
         verify_payload(signed, public_key).map_err(|_| ApiError::IncorrectPayloadSignature)?;
@@ -362,7 +377,7 @@ pub fn get_package_response(
 
 /// Create a request to download a version of a package as a tarball
 /// TODO: Where are the API docs for this?
-pub fn get_package_tarball_request(
+pub fn repository_get_package_tarball_request(
     name: &str,
     version: &str,
     api_key: Option<&str>,
@@ -381,7 +396,7 @@ pub fn get_package_tarball_request(
 
 /// Parse a response to download a version of a package as a tarball
 ///
-pub fn get_package_tarball_response(
+pub fn repository_get_package_tarball_response(
     response: http::Response<Vec<u8>>,
     checksum: &[u8],
 ) -> Result<Vec<u8>, ApiError> {
@@ -403,7 +418,7 @@ pub fn get_package_tarball_response(
 /// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.publish.ex#L384
 ///
 /// https://github.com/hexpm/hex/blob/main/lib/hex/api/release_docs.ex#L19
-pub fn remove_docs_request(
+pub fn api_remove_docs_request(
     package_name: &str,
     version: &str,
     api_key: &str,
@@ -421,7 +436,7 @@ pub fn remove_docs_request(
         .expect("remove_docs_request request"))
 }
 
-pub fn remove_docs_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
+pub fn api_remove_docs_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
     let (parts, body) = response.into_parts();
     match parts.status {
         StatusCode::NO_CONTENT => Ok(()),
@@ -438,7 +453,7 @@ pub fn remove_docs_response(response: http::Response<Vec<u8>>) -> Result<(), Api
 /// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.publish.ex#L429
 ///
 /// https://github.com/hexpm/hex/blob/main/lib/hex/api/release_docs.ex#L11
-pub fn publish_docs_request(
+pub fn api_publish_docs_request(
     package_name: &str,
     version: &str,
     gzipped_tarball: Vec<u8>,
@@ -459,7 +474,7 @@ pub fn publish_docs_request(
         .expect("publish_docs_request request"))
 }
 
-pub fn publish_docs_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
+pub fn api_publish_docs_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
     let (parts, body) = response.into_parts();
     match parts.status {
         StatusCode::CREATED => Ok(()),
@@ -476,7 +491,7 @@ pub fn publish_docs_response(response: http::Response<Vec<u8>>) -> Result<(), Ap
 /// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.publish.ex#L512
 ///
 /// https://github.com/hexpm/hex/blob/main/lib/hex/api/release.ex#L13
-pub fn publish_package_request(
+pub fn api_publish_package_request(
     release_tarball: Vec<u8>,
     api_key: &str,
     config: &Config,
@@ -494,7 +509,7 @@ pub fn publish_package_request(
         .expect("publish_package_request request")
 }
 
-pub fn publish_package_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
+pub fn api_publish_package_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
     // TODO: return data from body
     let (parts, body) = response.into_parts();
     match parts.status {
@@ -519,7 +534,7 @@ pub fn publish_package_response(response: http::Response<Vec<u8>>) -> Result<(),
 /// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.publish.ex#L371
 ///
 /// https://github.com/hexpm/hex/blob/main/lib/hex/api/release.ex#L21
-pub fn revert_release_request(
+pub fn api_revert_release_request(
     package_name: &str,
     version: &str,
     api_key: &str,
@@ -537,7 +552,7 @@ pub fn revert_release_request(
         .expect("publish_package_request request"))
 }
 
-pub fn revert_release_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
+pub fn api_revert_release_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
     let (parts, body) = response.into_parts();
     match parts.status {
         StatusCode::NO_CONTENT => Ok(()),
@@ -572,7 +587,7 @@ impl Display for OwnerLevel {
 /// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.owner.ex#L107
 ///
 /// https://github.com/hexpm/hex/blob/main/lib/hex/api/package.ex#L19
-pub fn add_owner_request(
+pub fn api_add_owner_request(
     package_name: &str,
     owner: &str,
     level: OwnerLevel,
@@ -594,7 +609,7 @@ pub fn add_owner_request(
         .expect("add_owner_request request")
 }
 
-pub fn add_owner_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
+pub fn api_add_owner_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
     let (parts, body) = response.into_parts();
     match parts.status {
         StatusCode::NO_CONTENT => Ok(()),
@@ -611,7 +626,7 @@ pub fn add_owner_response(response: http::Response<Vec<u8>>) -> Result<(), ApiEr
 /// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.owner.ex#L125
 ///
 /// https://github.com/hexpm/hex/blob/main/lib/hex/api/package.ex#L19
-pub fn transfer_owner_request(
+pub fn api_transfer_owner_request(
     package_name: &str,
     owner: &str,
     api_key: &str,
@@ -632,7 +647,7 @@ pub fn transfer_owner_request(
         .expect("transfer_owner_request request")
 }
 
-pub fn transfer_owner_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
+pub fn api_transfer_owner_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
     let (parts, body) = response.into_parts();
     match parts.status {
         StatusCode::NO_CONTENT => Ok(()),
@@ -649,7 +664,7 @@ pub fn transfer_owner_response(response: http::Response<Vec<u8>>) -> Result<(),
 /// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.owner.ex#L139
 ///
 /// https://github.com/hexpm/hex/blob/main/lib/hex/api/package.ex#L28
-pub fn remove_owner_request(
+pub fn api_remove_owner_request(
     package_name: &str,
     owner: &str,
     api_key: &str,
@@ -665,7 +680,7 @@ pub fn remove_owner_request(
         .expect("remove_owner_request request")
 }
 
-pub fn remove_owner_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
+pub fn api_remove_owner_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
     let (parts, body) = response.into_parts();
     match parts.status {
         StatusCode::NO_CONTENT => Ok(()),
@@ -739,6 +754,10 @@ impl ApiError {
     pub fn is_not_found(&self) -> bool {
         matches!(self, Self::NotFound)
     }
+
+    pub fn is_invalid_protobuf(&self) -> bool {
+        matches!(self, Self::InvalidProtobuf(_))
+    }
 }
 
 /// Read a body and ensure it has the given sha256 digest.
@@ -790,7 +809,8 @@ fn proto_to_retirement_reason(reason: proto::package::RetirementReason) -> Retir
 fn proto_to_dep(dep: proto::package::Dependency) -> Result<(String, Dependency), ApiError> {
     let app = dep.app;
     let repository = dep.repository;
-    let requirement = Range::new(dep.requirement);
+    let requirement = Range::new(dep.requirement.clone())
+        .map_err(|_| ApiError::InvalidVersionFormat(dep.requirement))?;
     Ok((
         dep.package,
         Dependency {
@@ -856,10 +876,6 @@ impl<Meta> Release<Meta> {
     pub fn is_retired(&self) -> bool {
         self.retirement_status.is_some()
     }
-
-    fn is_pre(&self) -> bool {
-        self.version.is_pre()
-    }
 }
 
 #[derive(Debug, PartialEq, Eq, Clone, serde::Deserialize)]
@@ -926,26 +942,6 @@ pub struct Dependency {
     pub repository: Option<String>,
 }
 
-impl Dependency {
-    pub(crate) fn from_range(range: Range) -> Self {
-        Dependency {
-            app: None,
-            optional: false,
-            repository: None,
-            requirement: range,
-        }
-    }
-
-    pub(crate) fn from_version(version: &Version) -> Self {
-        Dependency {
-            app: None,
-            optional: false,
-            repository: None,
-            requirement: Range::new(version.to_string()),
-        }
-    }
-}
-
 static USER_AGENT: &str = concat!(env!("CARGO_PKG_NAME"), " (", env!("CARGO_PKG_VERSION"), ")");
 
 fn validate_package_and_version(package: &str, version: &str) -> Result<(), ApiError> {
@@ -994,7 +990,7 @@ fn verify_payload(mut signed: Signed, pem_public_key: &[u8]) -> Result<Vec<u8>,
 
 /// Create a request to get the information for a package release.
 ///
-pub fn get_package_release_request(
+pub fn api_get_package_release_request(
     name: &str,
     version: &str,
     api_key: Option<&str>,
@@ -1013,7 +1009,7 @@ pub fn get_package_release_request(
 
 /// Parse a response to get the information for a package release.
 ///
-pub fn get_package_release_response(
+pub fn api_get_package_release_response(
     response: http::Response<Vec<u8>>,
 ) -> Result<Release<ReleaseMeta>, ApiError> {
     let (parts, body) = response.into_parts();
