@@ -1,7 +1,7 @@
 // TODO: remove all the async stuff and mockito server. The library is pure now
 // so it isn't needed.
 
-use std::convert::TryFrom;
+use std::{convert::TryFrom, io::Cursor};
 
 use super::*;
 use mockito::Matcher;
@@ -61,8 +61,8 @@ async fn authenticate_test_success() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let secret = crate::create_api_key_response(
-        http_send(crate::create_api_key_request(
+    let secret = crate::api_create_api_key_response(
+        http_send(crate::api_create_api_key_request(
             username, password, name, &config,
         ))
         .await
@@ -98,8 +98,8 @@ async fn authenticate_test_rate_limted() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::create_api_key_response(
-        http_send(crate::create_api_key_request(
+    let result = crate::api_create_api_key_response(
+        http_send(crate::api_create_api_key_request(
             username, password, name, &config,
         ))
         .await
@@ -145,8 +145,8 @@ async fn authenticate_test_bad_creds() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::create_api_key_response(
-        http_send(crate::create_api_key_request(
+    let result = crate::api_create_api_key_response(
+        http_send(crate::api_create_api_key_request(
             username, password, name, &config,
         ))
         .await
@@ -184,8 +184,8 @@ async fn remove_docs_success() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::remove_docs_response(
-        http_send(crate::remove_docs_request(package, version, key, &config).unwrap())
+    let result = crate::api_remove_docs_response(
+        http_send(crate::api_remove_docs_request(package, version, key, &config).unwrap())
             .await
             .unwrap(),
     )
@@ -217,8 +217,8 @@ async fn revert_release_success() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::revert_release_response(
-        http_send(crate::revert_release_request(package, version, key, &config).unwrap())
+    let result = crate::api_revert_release_response(
+        http_send(crate::api_revert_release_request(package, version, key, &config).unwrap())
             .await
             .unwrap(),
     )
@@ -255,8 +255,8 @@ async fn add_owner_success() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::add_owner_response(
-        http_send(crate::add_owner_request(
+    let result = crate::api_add_owner_response(
+        http_send(crate::api_add_owner_request(
             package, owner, level, key, &config,
         ))
         .await
@@ -294,10 +294,12 @@ async fn transfer_owner_success() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::transfer_owner_response(
-        http_send(crate::transfer_owner_request(package, owner, key, &config))
-            .await
-            .unwrap(),
+    let result = crate::api_transfer_owner_response(
+        http_send(crate::api_transfer_owner_request(
+            package, owner, key, &config,
+        ))
+        .await
+        .unwrap(),
     )
     .unwrap();
 
@@ -327,10 +329,12 @@ async fn remove_owner_success() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::remove_owner_response(
-        http_send(crate::remove_owner_request(package, owner, key, &config))
-            .await
-            .unwrap(),
+    let result = crate::api_remove_owner_response(
+        http_send(crate::api_remove_owner_request(
+            package, owner, key, &config,
+        ))
+        .await
+        .unwrap(),
     )
     .unwrap();
 
@@ -356,8 +360,8 @@ async fn remove_key_success() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::remove_api_key_response(
-        http_send(crate::remove_api_key_request(name, key, &config))
+    let result = crate::api_remove_api_key_response(
+        http_send(crate::api_remove_api_key_request(name, key, &config))
             .await
             .unwrap(),
     )
@@ -385,8 +389,8 @@ async fn remove_key_success_2() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::remove_api_key_response(
-        http_send(crate::remove_api_key_request(name, key, &config))
+    let result = crate::api_remove_api_key_response(
+        http_send(crate::api_remove_api_key_request(name, key, &config))
             .await
             .unwrap(),
     )
@@ -418,8 +422,8 @@ async fn remove_docs_unknown_package_version() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::remove_docs_response(
-        http_send(crate::remove_docs_request(package, version, key, &config).unwrap())
+    let result = crate::api_remove_docs_response(
+        http_send(crate::api_remove_docs_request(package, version, key, &config).unwrap())
             .await
             .unwrap(),
     )
@@ -455,8 +459,8 @@ async fn remove_docs_rate_limted() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::remove_docs_response(
-        http_send(crate::remove_docs_request(package, version, key, &config).unwrap())
+    let result = crate::api_remove_docs_response(
+        http_send(crate::api_remove_docs_request(package, version, key, &config).unwrap())
             .await
             .unwrap(),
     )
@@ -499,8 +503,8 @@ async fn remove_docs_invalid_key() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::remove_docs_response(
-        http_send(crate::remove_docs_request(package, version, key, &config).unwrap())
+    let result = crate::api_remove_docs_response(
+        http_send(crate::api_remove_docs_request(package, version, key, &config).unwrap())
             .await
             .unwrap(),
     )
@@ -543,8 +547,8 @@ async fn remove_docs_forbidden() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::remove_docs_response(
-        http_send(crate::remove_docs_request(package, version, key, &config).unwrap())
+    let result = crate::api_remove_docs_response(
+        http_send(crate::api_remove_docs_request(package, version, key, &config).unwrap())
             .await
             .unwrap(),
     )
@@ -566,7 +570,7 @@ async fn remove_docs_bad_package_name() {
 
     let config = Config::new();
 
-    match crate::remove_docs_request(package, version, key, &config).unwrap_err() {
+    match crate::api_remove_docs_request(package, version, key, &config).unwrap_err() {
         ApiError::InvalidPackageNameFormat(p) if p == package => (),
         result => panic!("expected Err(ApiError::BadPackage), got {:?}", result),
     }
@@ -595,10 +599,12 @@ async fn publish_docs_success() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::publish_docs_response(
-        http_send(crate::publish_docs_request(package, version, tarball, key, &config).unwrap())
-            .await
-            .unwrap(),
+    let result = crate::api_publish_docs_response(
+        http_send(
+            crate::api_publish_docs_request(package, version, tarball, key, &config).unwrap(),
+        )
+        .await
+        .unwrap(),
     );
 
     match result {
@@ -618,7 +624,7 @@ async fn publish_docs_bad_package_name() {
 
     let config = Config::new();
 
-    match crate::publish_docs_request(package, version, tarball, key, &config).unwrap_err() {
+    match crate::api_publish_docs_request(package, version, tarball, key, &config).unwrap_err() {
         ApiError::InvalidPackageNameFormat(p) if p == package => (),
         result => panic!("expected Err(ApiError::BadPackage), got {:?}", result),
     }
@@ -633,7 +639,7 @@ async fn publish_docs_bad_package_version() {
 
     let config = Config::new();
 
-    match crate::publish_docs_request(package, version, tarball, key, &config).unwrap_err() {
+    match crate::api_publish_docs_request(package, version, tarball, key, &config).unwrap_err() {
         ApiError::InvalidVersionFormat(v) if v == version => (),
         result => panic!("expected ApiError::BadPackage, got {:?}", result),
     }
@@ -662,10 +668,12 @@ async fn publish_docs_not_found() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::publish_docs_response(
-        http_send(crate::publish_docs_request(package, version, tarball, key, &config).unwrap())
-            .await
-            .unwrap(),
+    let result = crate::api_publish_docs_response(
+        http_send(
+            crate::api_publish_docs_request(package, version, tarball, key, &config).unwrap(),
+        )
+        .await
+        .unwrap(),
     );
 
     match result {
@@ -699,10 +707,12 @@ async fn publish_docs_rate_limit() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::publish_docs_response(
-        http_send(crate::publish_docs_request(package, version, tarball, key, &config).unwrap())
-            .await
-            .unwrap(),
+    let result = crate::api_publish_docs_response(
+        http_send(
+            crate::api_publish_docs_request(package, version, tarball, key, &config).unwrap(),
+        )
+        .await
+        .unwrap(),
     );
 
     match result {
@@ -743,10 +753,12 @@ async fn publish_docs_invalid_api_key() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::publish_docs_response(
-        http_send(crate::publish_docs_request(package, version, tarball, key, &config).unwrap())
-            .await
-            .unwrap(),
+    let result = crate::api_publish_docs_response(
+        http_send(
+            crate::api_publish_docs_request(package, version, tarball, key, &config).unwrap(),
+        )
+        .await
+        .unwrap(),
     );
 
     match result {
@@ -787,10 +799,12 @@ async fn publish_docs_forbidden() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::publish_docs_response(
-        http_send(crate::publish_docs_request(package, version, tarball, key, &config).unwrap())
-            .await
-            .unwrap(),
+    let result = crate::api_publish_docs_response(
+        http_send(
+            crate::api_publish_docs_request(package, version, tarball, key, &config).unwrap(),
+        )
+        .await
+        .unwrap(),
     );
 
     match result {
@@ -801,6 +815,115 @@ async fn publish_docs_forbidden() {
     mock.assert();
 }
 
+fn expected_package_exfmt() -> Package {
+    Package {
+        name: "exfmt".to_string(),
+        repository: "hexpm".to_string(),
+        releases: vec![
+            Release {
+                version: Version::try_from("0.0.0").unwrap(),
+                requirements: [].into(),
+                retirement_status: None,
+                outer_checksum: vec![
+                    82, 48, 191, 145, 92, 172, 0, 108, 238, 71, 57, 23, 101, 177, 161, 83, 91, 182,
+                    18, 232, 249, 225, 29, 12, 246, 5, 215, 165, 32, 57, 179, 110,
+                ],
+                meta: (),
+            },
+            Release {
+                version: Version::try_from("0.1.0").unwrap(),
+                requirements: [].into(),
+                retirement_status: None,
+                outer_checksum: vec![
+                    111, 246, 240, 176, 118, 229, 12, 15, 164, 61, 186, 3, 89, 106, 153, 225, 247,
+                    52, 245, 8, 216, 139, 21, 232, 200, 16, 214, 59, 241, 188, 9, 6,
+                ],
+                meta: (),
+            },
+            Release {
+                version: Version::try_from("0.2.0").unwrap(),
+                requirements: [].into(),
+                retirement_status: None,
+                outer_checksum: vec![
+                    149, 9, 192, 229, 84, 162, 110, 207, 161, 43, 31, 0, 126, 168, 14, 243, 31, 43,
+                    195, 238, 100, 91, 78, 100, 213, 181, 101, 154, 106, 168, 170, 107,
+                ],
+                meta: (),
+            },
+            Release {
+                version: Version::try_from("0.2.1").unwrap(),
+                requirements: [].into(),
+                retirement_status: None,
+                outer_checksum: vec![
+                    157, 229, 28, 212, 92, 249, 14, 240, 235, 104, 31, 12, 160, 199, 83, 195, 154,
+                    105, 222, 37, 221, 80, 181, 183, 113, 240, 234, 107, 144, 85, 255, 65,
+                ],
+                meta: (),
+            },
+            Release {
+                version: Version::try_from("0.2.2").unwrap(),
+                requirements: [].into(),
+                retirement_status: None,
+                outer_checksum: vec![
+                    112, 250, 133, 189, 183, 192, 54, 218, 115, 55, 216, 97, 204, 201, 191, 168,
+                    250, 133, 138, 252, 202, 240, 74, 197, 228, 235, 81, 18, 241, 7, 155, 38,
+                ],
+                meta: (),
+            },
+            Release {
+                version: Version::try_from("0.2.3").unwrap(),
+                requirements: [].into(),
+                retirement_status: None,
+                outer_checksum: vec![
+                    131, 20, 29, 160, 171, 124, 7, 125, 210, 88, 17, 189, 199, 49, 191, 190, 14,
+                    162, 38, 247, 52, 176, 189, 17, 7, 188, 151, 152, 24, 64, 170, 29,
+                ],
+                meta: (),
+            },
+            Release {
+                version: Version::try_from("0.2.4").unwrap(),
+                requirements: [].into(),
+                retirement_status: None,
+                outer_checksum: vec![
+                    109, 162, 185, 169, 26, 4, 62, 60, 167, 54, 182, 161, 140, 197, 75, 113, 183,
+                    117, 247, 201, 218, 228, 14, 160, 115, 157, 196, 51, 108, 16, 96, 217,
+                ],
+                meta: (),
+            },
+            Release {
+                version: Version::try_from("0.3.0").unwrap(),
+                requirements: [].into(),
+                retirement_status: None,
+                outer_checksum: vec![
+                    97, 50, 95, 212, 242, 59, 245, 177, 140, 78, 79, 180, 108, 174, 119, 176, 24,
+                    80, 218, 152, 178, 227, 152, 242, 32, 126, 72, 67, 222, 0, 173, 170,
+                ],
+                meta: (),
+            },
+            Release {
+                version: Version::try_from("0.4.0").unwrap(),
+                requirements: [].into(),
+                retirement_status: None,
+                outer_checksum: vec![
+                    246, 178, 237, 214, 217, 158, 143, 52, 130, 186, 64, 50, 94, 175, 161, 81, 68,
+                    186, 4, 73, 53, 226, 235, 144, 209, 84, 231, 136, 165, 119, 122, 126,
+                ],
+                meta: (),
+            },
+            Release {
+                version: Version::try_from("0.5.0").unwrap(),
+                requirements: [].into(),
+                retirement_status: None,
+                outer_checksum: vec![
+                    151, 86, 157, 218, 218, 131, 240, 119, 198, 216, 202, 240, 65, 17, 57, 228, 84,
+                    252, 59, 207, 246, 49, 22, 21, 52, 47, 51, 139, 190, 9, 95, 109,
+                ],
+                meta: (),
+            },
+        ],
+    }
+}
+
 #[tokio::test]
 async fn get_package_ok_test() {
     let response_body = std::include_bytes!("../test/package_exfmt");
@@ -819,124 +942,17 @@ async fn get_package_ok_test() {
     let mut config = Config::new();
     config.repository_base = http::Uri::try_from(server.url()).unwrap();
 
-    let package = crate::get_package_response(
-        http_send(crate::get_package_request("exfmt", None, &config))
-            .await
-            .unwrap(),
+    let package = crate::repository_v2_get_package_response(
+        http_send(crate::repository_v2_get_package_request(
+            "exfmt", None, &config,
+        ))
+        .await
+        .unwrap(),
         std::include_bytes!("../test/public_key"),
     )
     .unwrap();
 
-    assert_eq!(
-        Package {
-            name: "exfmt".to_string(),
-            repository: "hexpm".to_string(),
-            releases: vec![
-                Release {
-                    version: Version::try_from("0.0.0").unwrap(),
-                    requirements: [].into(),
-                    retirement_status: None,
-                    outer_checksum: vec![
-                        82, 48, 191, 145, 92, 172, 0, 108, 238, 71, 57, 23, 101, 177, 161, 83, 91,
-                        182, 18, 232, 249, 225, 29, 12, 246, 5, 215, 165, 32, 57, 179, 110
-                    ],
-                    meta: (),
-                },
-                Release {
-                    version: Version::try_from("0.1.0").unwrap(),
-                    requirements: [].into(),
-                    retirement_status: None,
-                    outer_checksum: vec![
-                        111, 246, 240, 176, 118, 229, 12, 15, 164, 61, 186, 3, 89, 106, 153, 225,
-                        247, 52, 245, 8, 216, 139, 21, 232, 200, 16, 214, 59, 241, 188, 9, 6
-                    ],
-                    meta: (),
-                },
-                Release {
-                    version: Version::try_from("0.2.0").unwrap(),
-                    requirements: [].into(),
-                    retirement_status: None,
-                    outer_checksum: vec![
-                        149, 9, 192, 229, 84, 162, 110, 207, 161, 43, 31, 0, 126, 168, 14, 243, 31,
-                        43, 195, 238, 100, 91, 78, 100, 213, 181, 101, 154, 106, 168, 170, 107
-                    ],
-                    meta: (),
-                },
-                Release {
-                    version: Version::try_from("0.2.1").unwrap(),
-                    requirements: [].into(),
-                    retirement_status: None,
-                    outer_checksum: vec![
-                        157, 229, 28, 212, 92, 249, 14, 240, 235, 104, 31, 12, 160, 199, 83, 195,
-                        154, 105, 222, 37, 221, 80, 181, 183, 113, 240, 234, 107, 144, 85, 255, 65
-                    ],
-                    meta: (),
-                },
-                Release {
-                    version: Version::try_from("0.2.2").unwrap(),
-                    requirements: [].into(),
-                    retirement_status: None,
-                    outer_checksum: vec![
-                        112, 250, 133, 189, 183, 192, 54, 218, 115, 55, 216, 97, 204, 201, 191,
-                        168, 250, 133, 138, 252, 202, 240, 74, 197, 228, 235, 81, 18, 241, 7, 155,
-                        38
-                    ],
-                    meta: (),
-                },
-                Release {
-                    version: Version::try_from("0.2.3").unwrap(),
-                    requirements: [].into(),
-                    retirement_status: None,
-                    outer_checksum: vec![
-                        131, 20, 29, 160, 171, 124, 7, 125, 210, 88, 17, 189, 199, 49, 191, 190,
-                        14, 162, 38, 247, 52, 176, 189, 17, 7, 188, 151, 152, 24, 64, 170, 29
-                    ],
-                    meta: (),
-                },
-                Release {
-                    version: Version::try_from("0.2.4").unwrap(),
-                    requirements: [].into(),
-                    retirement_status: None,
-                    outer_checksum: vec![
-                        109, 162, 185, 169, 26, 4, 62, 60, 167, 54, 182, 161, 140, 197, 75, 113,
-                        183, 117, 247, 201, 218, 228, 14, 160, 115, 157, 196, 51, 108, 16, 96, 217
-                    ],
-                    meta: (),
-                },
-                Release {
-                    version: Version::try_from("0.3.0").unwrap(),
-                    requirements: [].into(),
-                    retirement_status: None,
-                    outer_checksum: vec![
-                        97, 50, 95, 212, 242, 59, 245, 177, 140, 78, 79, 180, 108, 174, 119, 176,
-                        24, 80, 218, 152, 178, 227, 152, 242, 32, 126, 72, 67, 222, 0, 173, 170
-                    ],
-                    meta: (),
-                },
-                Release {
-                    version: Version::try_from("0.4.0").unwrap(),
-                    requirements: [].into(),
-                    retirement_status: None,
-                    outer_checksum: vec![
-                        246, 178, 237, 214, 217, 158, 143, 52, 130, 186, 64, 50, 94, 175, 161, 81,
-                        68, 186, 4, 73, 53, 226, 235, 144, 209, 84, 231, 136, 165, 119, 122, 126
-                    ],
-                    meta: (),
-                },
-                Release {
-                    version: Version::try_from("0.5.0").unwrap(),
-                    requirements: [].into(),
-                    retirement_status: None,
-                    outer_checksum: vec![
-                        151, 86, 157, 218, 218, 131, 240, 119, 198, 216, 202, 240, 65, 17, 57, 228,
-                        84, 252, 59, 207, 246, 49, 22, 21, 52, 47, 51, 139, 190, 9, 95, 109
-                    ],
-                    meta: (),
-                }
-            ],
-        },
-        package,
-    );
+    assert_eq!(expected_package_exfmt(), package,);
 
     mock.assert();
 }
@@ -944,8 +960,8 @@ async fn get_package_ok_test() {
 #[tokio::test]
 async fn get_package_not_found() {
     let config = Config::new();
-    let error = crate::get_package_response(
-        http_send(crate::get_package_request(
+    let error = crate::repository_v2_get_package_response(
+        http_send(crate::repository_v2_get_package_request(
             "louissaysthispackagedoesnotexist",
             None,
             &config,
@@ -959,6 +975,34 @@ async fn get_package_not_found() {
     assert!(error.is_not_found());
 }
 
+#[tokio::test]
+async fn get_package_from_bytes_ok() {
+    let response_body = std::include_bytes!("../test/package_exfmt");
+    let mut uncompressed = Vec::new();
+    let mut decoder = GzDecoder::new(Cursor::new(response_body));
+    let _ = decoder
+        .read_to_end(&mut uncompressed)
+        .expect("failed to decompress body");
+
+    let package = crate::repository_v2_package_parse_body(
+        &uncompressed,
+        std::include_bytes!("../test/public_key"),
+    )
+    .expect("package failed to parse");
+
+    assert_eq!(expected_package_exfmt(), package,);
+}
+
+#[tokio::test]
+async fn get_package_from_bytes_malformed() {
+    // public key should not be a valid protobuf and should therefore fail
+    let bytes = std::include_bytes!("../test/public_key").to_vec();
+    let package_error = crate::repository_v2_package_parse_body(&bytes, &bytes)
+        .expect_err("parsing failed to fail");
+
+    assert!(package_error.is_invalid_protobuf());
+}
+
 #[tokio::test]
 async fn get_repository_versions_ok_test() {
     let response_body = std::include_bytes!("../test/versions");
@@ -977,8 +1021,8 @@ async fn get_repository_versions_ok_test() {
     let mut config = Config::new();
     config.repository_base = http::Uri::try_from(server.url()).unwrap();
 
-    let versions = crate::get_repository_versions_response(
-        http_send(crate::get_repository_versions_request(None, &config))
+    let versions = crate::repository_v2_get_versions_response(
+        http_send(crate::repository_v2_get_versions_request(None, &config))
             .await
             .unwrap(),
         std::include_bytes!("../test/public_key"),
@@ -1003,14 +1047,56 @@ async fn get_repository_versions_ok_test() {
     mock.assert();
 }
 
+#[tokio::test]
+async fn get_repository_versions_from_bytes_ok() {
+    let response_body = std::include_bytes!("../test/versions");
+    let mut uncompressed = Vec::new();
+    let mut decoder = GzDecoder::new(Cursor::new(response_body));
+    let _ = decoder
+        .read_to_end(&mut uncompressed)
+        .expect("failed to decompress body");
+
+    let versions = crate::repository_v2_get_versions_body(
+        &uncompressed,
+        std::include_bytes!("../test/public_key"),
+    )
+    .expect("versions failed to parse");
+
+    assert_eq!(
+        &vec![
+            Version::parse("0.0.0").unwrap(),
+            Version::parse("0.1.0").unwrap(),
+            Version::parse("0.2.0").unwrap(),
+            Version::parse("0.2.1").unwrap(),
+            Version::parse("0.2.2").unwrap(),
+            Version::parse("0.2.3").unwrap(),
+            Version::parse("0.2.4").unwrap(),
+            Version::parse("0.3.0").unwrap(),
+            Version::parse("0.4.0").unwrap(),
+            Version::parse("0.5.0").unwrap(),
+        ],
+        versions.get("exfmt").unwrap(),
+    );
+}
+
+#[tokio::test]
+async fn get_repository_versions_from_bytes_malformed() {
+    // public key should not be a valid protobuf and should therefore fail
+    let bytes = std::include_bytes!("../test/public_key").to_vec();
+    let versions_error =
+        crate::repository_v2_get_versions_body(&bytes, &bytes).expect_err("parsing failed to fail");
+
+    assert!(versions_error.is_invalid_protobuf());
+}
+
 #[tokio::test]
 async fn get_repository_tarball_ok_test() {
     let config = Config::new();
     let checksum =
         base16::decode("9107f6a859cb96945ad9a099085db028ca2bebb3c8ea42eec227b51c614cc2e0").unwrap();
 
-    let downloaded = crate::get_package_tarball_response(
-        http_send(crate::get_package_tarball_request(
+    let downloaded = crate::repository_get_package_tarball_response(
+        http_send(crate::repository_get_package_tarball_request(
             "gleam_stdlib",
             "0.14.0",
             None,
@@ -1033,8 +1119,8 @@ async fn get_repository_tarball_bad_checksum_test() {
     let config = Config::new();
     let checksum = vec![1, 2, 3, 4, 5];
 
-    let err = crate::get_package_tarball_response(
-        http_send(crate::get_package_tarball_request(
+    let err = crate::repository_get_package_tarball_response(
+        http_send(crate::repository_get_package_tarball_request(
             "gleam_stdlib",
             "0.14.0",
             None,
@@ -1057,8 +1143,8 @@ async fn get_repository_tarball_not_found_test() {
     let config = Config::new();
     let checksum = vec![1, 2, 3, 4, 5];
 
-    let err = crate::get_package_tarball_response(
-        http_send(crate::get_package_tarball_request(
+    let err = crate::repository_get_package_tarball_response(
+        http_send(crate::repository_get_package_tarball_request(
             "gleam_stdlib",
             "unknown-version",
             None,
@@ -1091,10 +1177,12 @@ async fn publish_package_success() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::publish_package_response(
-        http_send(crate::publish_package_request(tarball, key, &config, false))
-            .await
-            .unwrap(),
+    let result = crate::api_publish_package_response(
+        http_send(crate::api_publish_package_request(
+            tarball, key, &config, false,
+        ))
+        .await
+        .unwrap(),
     );
 
     match result {
@@ -1130,10 +1218,12 @@ async fn modify_package_late() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::publish_package_response(
-        http_send(crate::publish_package_request(tarball, key, &config, true))
-            .await
-            .unwrap(),
+    let result = crate::api_publish_package_response(
+        http_send(crate::api_publish_package_request(
+            tarball, key, &config, true,
+        ))
+        .await
+        .unwrap(),
     );
 
     match result {
@@ -1169,10 +1259,12 @@ async fn not_replacing() {
     let mut config = Config::new();
     config.api_base = http::Uri::try_from(server.url()).unwrap();
 
-    let result = crate::publish_package_response(
-        http_send(crate::publish_package_request(tarball, key, &config, false))
-            .await
-            .unwrap(),
+    let result = crate::api_publish_package_response(
+        http_send(crate::api_publish_package_request(
+            tarball, key, &config, false,
+        ))
+        .await
+        .unwrap(),
     );
 
     match result {
@@ -1186,8 +1278,8 @@ async fn not_replacing() {
 #[tokio::test]
 async fn get_package_release_not_found() {
     let config = Config::new();
-    let error = crate::get_package_release_response(
-        http_send(crate::get_package_release_request(
+    let error = crate::api_get_package_release_response(
+        http_send(crate::api_get_package_release_request(
             "louissaysthispackagedoesnotexist",
             "1.0.1",
             None,
@@ -1204,8 +1296,8 @@ async fn get_package_release_not_found() {
 #[tokio::test]
 async fn get_package_release_ok() {
     let config = Config::new();
-    let resp = crate::get_package_release_response(
-        http_send(crate::get_package_release_request(
+    let resp = crate::api_get_package_release_response(
+        http_send(crate::api_get_package_release_request(
             "clint", "0.0.1", None, &config,
         ))
         .await
@@ -1221,7 +1313,7 @@ async fn get_package_release_ok() {
                 (
                     "plug".into(),
                     Dependency {
-                        requirement: Range::new("~>0.11.0".into()),
+                        requirement: Range::new("~>0.11.0".into()).unwrap(),
                         optional: false,
                         app: Some("plug".into()),
                         repository: None
@@ -1230,7 +1322,7 @@ async fn get_package_release_ok() {
                 (
                     "cowboy".into(),
                     Dependency {
-                        requirement: Range::new("~>1.0.0".into()),
+                        requirement: Range::new("~>1.0.0".into()).unwrap(),
                         optional: false,
                         app: Some("cowboy".into()),
                         repository: None
